#import "SWGDNSApi.h"
#import "SWGQueryParamCollection.h"
#import "SWGInlineResponse2003.h"
#import "SWGInlineResponse2004.h"


@interface SWGDNSApi ()

@property (nonatomic, strong) NSMutableDictionary *defaultHeaders;

@end

@implementation SWGDNSApi

NSString* kSWGDNSApiErrorDomain = @"SWGDNSApiErrorDomain";
NSInteger kSWGDNSApiMissingParamErrorCode = 234513;

@synthesize apiClient = _apiClient;

#pragma mark - Initialize methods

- (instancetype) init {
    self = [super init];
    if (self) {
        SWGConfiguration *config = [SWGConfiguration sharedConfig];
        if (config.apiClient == nil) {
            config.apiClient = [[SWGApiClient alloc] init];
        }
        _apiClient = config.apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

- (id) initWithApiClient:(SWGApiClient *)apiClient {
    self = [super init];
    if (self) {
        _apiClient = apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

#pragma mark -

+ (instancetype)sharedAPI {
    static SWGDNSApi *sharedAPI;
    static dispatch_once_t once;
    dispatch_once(&once, ^{
        sharedAPI = [[self alloc] init];
    });
    return sharedAPI;
}

-(NSString*) defaultHeaderForKey:(NSString*)key {
    return self.defaultHeaders[key];
}

-(void) addHeader:(NSString*)value forKey:(NSString*)key {
    [self setDefaultHeaderValue:value forKey:key];
}

-(void) setDefaultHeaderValue:(NSString*) value forKey:(NSString*)key {
    [self.defaultHeaders setValue:value forKey:key];
}

-(NSUInteger) requestQueueSize {
    return [SWGApiClient requestQueueSize];
}

#pragma mark - Api Methods

///
/// Создание записи домена
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param addDnsZone зона, которую необходимо создать 
///
///  @param addDnsRecord  (optional)
///
///  @param iisSiteForDns ID сайта из /website/list, либо IP-адрес виртуального сервера, к которому необходимо сделать привязку (optional)
///
///  @param bindOnly  (optional)
///
///  @returns NSString*
///
-(NSNumber*) dnsAddGetWithToken_: (NSString*) token_
    addDnsZone: (NSString*) addDnsZone
    addDnsRecord: (NSString*) addDnsRecord
    iisSiteForDns: (NSString*) iisSiteForDns
    bindOnly: (NSNumber*) bindOnly
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'addDnsZone' is set
    if (addDnsZone == nil) {
        NSParameterAssert(addDnsZone);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"addDnsZone"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/add"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (addDnsZone != nil) {
        queryParams[@"add_dns_zone"] = addDnsZone;
    }
    if (addDnsRecord != nil) {
        queryParams[@"add_dns_record"] = addDnsRecord;
    }
    if (iisSiteForDns != nil) {
        queryParams[@"iis_site_for_dns"] = iisSiteForDns;
    }
    if (bindOnly != nil) {
        queryParams[@"bind_only"] = bindOnly;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Привязка одного домена к другому
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID домена из списка /dns/list 
///
///  @param bindTo домен, к которому необходимо сделать привязку (optional)
///
///  @returns NSString*
///
-(NSNumber*) dnsBindGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    bindTo: (NSString*) bindTo
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/bind"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (bindTo != nil) {
        queryParams[@"bind_to"] = bindTo;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Получить список доменных имён
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @returns NSArray<SWGInlineResponse2003>*
///
-(NSNumber*) dnsListGetWithToken_: (NSString*) token_
    completionHandler: (void (^)(NSArray<SWGInlineResponse2003>* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGInlineResponse2003>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGInlineResponse2003>*)data, error);
                                }
                           }
          ];
}

///
/// Информация по продлению доменов
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @returns NSArray<SWGInlineResponse2004>*
///
-(NSNumber*) dnsProlongListGetWithToken_: (NSString*) token_
    completionHandler: (void (^)(NSArray<SWGInlineResponse2004>* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/prolong/list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGInlineResponse2004>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGInlineResponse2004>*)data, error);
                                }
                           }
          ];
}

///
/// Редактирование \"сырой\" зоны
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID домена из /dns/list 
///
///  @param sDel Значение '1' сообщает, что запись необходимо удалить 
///
///  @param sAdd Значение '1' сообщает, что запись необходимо создать 
///
///  @param dnsType Тип записи: A, MX, CNAME, AAAA, NS, TXT, SRV 
///
///  @param dnsName Имя записи, либо '@' для корневой 
///
///  @param dnsValue Содержание записи (для A это IP-адрес, для CNAME имя, для MX приоритет и назначение) 
///
///  @returns NSString*
///
-(NSNumber*) dnsRawGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    sDel: (NSNumber*) sDel
    sAdd: (NSNumber*) sAdd
    dnsType: (NSString*) dnsType
    dnsName: (NSString*) dnsName
    dnsValue: (NSString*) dnsValue
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'sDel' is set
    if (sDel == nil) {
        NSParameterAssert(sDel);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"sDel"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'sAdd' is set
    if (sAdd == nil) {
        NSParameterAssert(sAdd);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"sAdd"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'dnsType' is set
    if (dnsType == nil) {
        NSParameterAssert(dnsType);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"dnsType"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'dnsName' is set
    if (dnsName == nil) {
        NSParameterAssert(dnsName);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"dnsName"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'dnsValue' is set
    if (dnsValue == nil) {
        NSParameterAssert(dnsValue);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"dnsValue"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/raw"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (sDel != nil) {
        queryParams[@"s_del"] = sDel;
    }
    if (sAdd != nil) {
        queryParams[@"s_add"] = sAdd;
    }
    if (dnsType != nil) {
        queryParams[@"dns_type"] = dnsType;
    }
    if (dnsName != nil) {
        queryParams[@"dns_name"] = dnsName;
    }
    if (dnsValue != nil) {
        queryParams[@"dns_value"] = dnsValue;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Редактировать DNS-зону
/// 
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID домена из /dns/list 
///
///  @param managedMx Значение '1', если необходимо включить поддержку на MX-серверах хостинга и '0', если выключить 
///
///  @param updManagedMx Значение '1' подтверждает операцию 
///
///  @returns NSString*
///
-(NSNumber*) dnsRawManagedmxGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    managedMx: (NSNumber*) managedMx
    updManagedMx: (NSNumber*) updManagedMx
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'managedMx' is set
    if (managedMx == nil) {
        NSParameterAssert(managedMx);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"managedMx"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'updManagedMx' is set
    if (updManagedMx == nil) {
        NSParameterAssert(updManagedMx);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"updManagedMx"] };
            NSError* error = [NSError errorWithDomain:kSWGDNSApiErrorDomain code:kSWGDNSApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/dns/raw/managedmx"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (managedMx != nil) {
        queryParams[@"managed_mx"] = managedMx;
    }
    if (updManagedMx != nil) {
        queryParams[@"upd_managed_mx"] = updManagedMx;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}



@end
