#import "SWGVDSHyperVOpenVZApi.h"
#import "SWGQueryParamCollection.h"
#import "SWGInlineResponse20011.h"
#import "SWGInlineResponse20012.h"
#import "SWGInlineResponse20013.h"


@interface SWGVDSHyperVOpenVZApi ()

@property (nonatomic, strong) NSMutableDictionary *defaultHeaders;

@end

@implementation SWGVDSHyperVOpenVZApi

NSString* kSWGVDSHyperVOpenVZApiErrorDomain = @"SWGVDSHyperVOpenVZApiErrorDomain";
NSInteger kSWGVDSHyperVOpenVZApiMissingParamErrorCode = 234513;

@synthesize apiClient = _apiClient;

#pragma mark - Initialize methods

- (instancetype) init {
    self = [super init];
    if (self) {
        SWGConfiguration *config = [SWGConfiguration sharedConfig];
        if (config.apiClient == nil) {
            config.apiClient = [[SWGApiClient alloc] init];
        }
        _apiClient = config.apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

- (id) initWithApiClient:(SWGApiClient *)apiClient {
    self = [super init];
    if (self) {
        _apiClient = apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

#pragma mark -

+ (instancetype)sharedAPI {
    static SWGVDSHyperVOpenVZApi *sharedAPI;
    static dispatch_once_t once;
    dispatch_once(&once, ^{
        sharedAPI = [[self alloc] init];
    });
    return sharedAPI;
}

-(NSString*) defaultHeaderForKey:(NSString*)key {
    return self.defaultHeaders[key];
}

-(void) addHeader:(NSString*)value forKey:(NSString*)key {
    [self setDefaultHeaderValue:value forKey:key];
}

-(void) setDefaultHeaderValue:(NSString*) value forKey:(NSString*)key {
    [self.defaultHeaders setValue:value forKey:key];
}

-(NSUInteger) requestQueueSize {
    return [SWGApiClient requestQueueSize];
}

#pragma mark - Api Methods

///
/// Изменение параметров VDS
/// Изменение параметров уже существующего VDS
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param type Тип создаваемого VDS. 'vz1', 'vz2', 'vz3', 'vz4', 'vz5' или 'vds.dynamic'. По умолчанию 'vds.dynamic' (optional)
///
///  @param crHvmem Количество доступной памяти в мегабайтах. По умолчанию 2048 (optional)
///
///  @param crHvdsk Количество доступных гигабайт диска. По умолчанию 30 (optional)
///
///  @param crHvcpu Количество ядер CPU. По умолчанию 2 (optional)
///
///  @param template Шаблон и тип виртуализации VDS. За подробностями см. /vds/templates-list (optional)
///
///  @param forceMemo  (optional)
///
///  @param hv1gbPanelVersion  (optional)
///
///  @param panelInstall Необходимо ли установить панель 1Gb на VDS (optional)
///
///  @param crSsd1 Создать всю систему на SSD (optional)
///
///  @param crHvAllSystem Создать всю систему на одном диске большого размера (иначе — системный диск + диск с данными) (optional)
///
///  @returns NSString*
///
-(NSNumber*) vdsCreateGetWithToken_: (NSString*) token_
    type: (NSString*) type
    crHvmem: (NSNumber*) crHvmem
    crHvdsk: (NSNumber*) crHvdsk
    crHvcpu: (NSNumber*) crHvcpu
    template: (NSString*) template
    forceMemo: (NSString*) forceMemo
    hv1gbPanelVersion: (NSString*) hv1gbPanelVersion
    panelInstall: (NSNumber*) panelInstall
    crSsd1: (NSNumber*) crSsd1
    crHvAllSystem: (NSNumber*) crHvAllSystem
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/create"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (type != nil) {
        queryParams[@"type"] = type;
    }
    if (crHvmem != nil) {
        queryParams[@"cr_hvmem"] = crHvmem;
    }
    if (crHvdsk != nil) {
        queryParams[@"cr_hvdsk"] = crHvdsk;
    }
    if (crHvcpu != nil) {
        queryParams[@"cr_hvcpu"] = crHvcpu;
    }
    if (template != nil) {
        queryParams[@"template"] = template;
    }
    if (forceMemo != nil) {
        queryParams[@"force_memo"] = forceMemo;
    }
    if (hv1gbPanelVersion != nil) {
        queryParams[@"hv_1gb_panel_version"] = hv1gbPanelVersion;
    }
    if (panelInstall != nil) {
        queryParams[@"panel_install"] = panelInstall;
    }
    if (crSsd1 != nil) {
        queryParams[@"cr_ssd1"] = crSsd1;
    }
    if (crHvAllSystem != nil) {
        queryParams[@"cr_hv_all_system"] = crHvAllSystem;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Удаление VDS
/// Предоставляет функционал для удаления VDS
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list 
///
///  @param forceCritical Если true, VDS будет удален срочно (optional)
///
///  @returns NSString*
///
-(NSNumber*) vdsDeleteGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    forceCritical: (NSNumber*) forceCritical
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/delete"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (forceCritical != nil) {
        queryParams[@"force_critical"] = forceCritical;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Добавление IP на VDS
/// Этот вызов позволяет добавить ещё один IP адрес на указанный VDS
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list 
///
///  @returns NSString*
///
-(NSNumber*) vdsIpAddGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/ip/add"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Удаление IP с VDS
/// Этот вызов позволяет отвязать IP адрес от VDS
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list 
///
///  @param delIp IP адрес, который необходимо удалить 
///
///  @returns NSString*
///
-(NSNumber*) vdsIpDeleteGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    delIp: (NSString*) delIp
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'delIp' is set
    if (delIp == nil) {
        NSParameterAssert(delIp);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"delIp"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/ip/delete"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (delIp != nil) {
        queryParams[@"del_ip"] = delIp;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Список IP-адресов виртуальных серверов
/// Список IP-адресов виртуальных серверов
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list (optional)
///
///  @returns NSArray<SWGInlineResponse20011>*
///
-(NSNumber*) vdsIpListGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    completionHandler: (void (^)(NSArray<SWGInlineResponse20011>* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/ip/list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGInlineResponse20011>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGInlineResponse20011>*)data, error);
                                }
                           }
          ];
}

///
/// Список виртуальных серверов
/// Позволяет получить список виртуальных серверов
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера. Если задан, то будет выдана информация только для этого VDS (optional)
///
///  @returns NSArray<SWGInlineResponse20012>*
///
-(NSNumber*) vdsListGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    completionHandler: (void (^)(NSArray<SWGInlineResponse20012>* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGInlineResponse20012>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGInlineResponse20012>*)data, error);
                                }
                           }
          ];
}

///
/// Перезагрузка VDS
/// Предоставляет функционал для перезагрузки VDS
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list 
///
///  @returns NSString*
///
-(NSNumber*) vdsRebootGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/reboot"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}

///
/// Список шаблонов виртуальных серверов
/// Позволяет получить список шаблонов виртуальных серверов
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @returns NSArray<SWGInlineResponse20013>*
///
-(NSNumber*) vdsTemplatesListGetWithToken_: (NSString*) token_
    completionHandler: (void (^)(NSArray<SWGInlineResponse20013>* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/templates-list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGInlineResponse20013>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGInlineResponse20013>*)data, error);
                                }
                           }
          ];
}

///
/// Создание VDS
/// Создание новых VDS с произвольными характеристиками
///  @param token_ Ключ доступа, полученный при авторизации 
///
///  @param key_ ID виртуального сервера, полученный из /vds/list 
///
///  @param crHvmem Количество доступной памяти в мегабайтах. По умолчанию 2048 (optional)
///
///  @param crHvdsk Количество доступных гигабайт диска. По умолчанию 30 (optional)
///
///  @param crHvcpu Количество ядер CPU. По умолчанию 2 (optional)
///
///  @returns NSString*
///
-(NSNumber*) vdsUpdateGetWithToken_: (NSString*) token_
    key_: (NSNumber*) key_
    crHvmem: (NSNumber*) crHvmem
    crHvdsk: (NSNumber*) crHvdsk
    crHvcpu: (NSNumber*) crHvcpu
    completionHandler: (void (^)(NSString* output, NSError* error)) handler {
    // verify the required parameter 'token_' is set
    if (token_ == nil) {
        NSParameterAssert(token_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"token_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'key_' is set
    if (key_ == nil) {
        NSParameterAssert(key_);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"key_"] };
            NSError* error = [NSError errorWithDomain:kSWGVDSHyperVOpenVZApiErrorDomain code:kSWGVDSHyperVOpenVZApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/vds/update"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (token_ != nil) {
        queryParams[@"_token_"] = token_;
    }
    if (key_ != nil) {
        queryParams[@"_key_"] = key_;
    }
    if (crHvmem != nil) {
        queryParams[@"cr_hvmem"] = crHvmem;
    }
    if (crHvdsk != nil) {
        queryParams[@"cr_hvdsk"] = crHvdsk;
    }
    if (crHvcpu != nil) {
        queryParams[@"cr_hvcpu"] = crHvcpu;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"application/json"]];

    // Authentication setting
    NSArray *authSettings = @[];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSString*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSString*)data, error);
                                }
                           }
          ];
}



@end
